close all
clear all
clc


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%% ECUACIONES DIFERENCIALES %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% temas selectos de biologa matemtica, 
%%% semestre 2017-II, 
%%% Elisa Domnguez Httinger



%% Ecuacin lineal

% declaramos a la ODE como una funcin annima, de la manera:
% nombre_funcin=@(parmetro_de_la_funcin1,parmetro_de_la_funcin2,..)funcin.
% Como es una ODE, necesitamos los siguientes argumentos:
% nombre_ode=@(tiempo_de_integracin, condiciones_iniciales, parmetros)ODE

linear_degradation=@(t,y, a)-y*a;

% Parmetro:
a=1;
% condicin inicial:
y0=10;

%tiempo de integracin
tspan = [0 10];

%integramos  numricamente:
[t,y] = ode45(@(t,y)linear_degradation(t,y,a),tspan,y0,a);

% pintamos la funcin 
figure
plot(t,y,'color','b', 'LineWidth',2)
xlabel('Time t');
ylabel('y(t) decaimiento lineal');

% ahora vamos a ver qu pasa si aumentamos el parmetro de decaimiento:
hold on
a=10;
[t,y] = ode45(@(t,y)linear_degradation(t,y,a),tspan,y0,a);
plot(t,y(:,1),'color','r', 'LineWidth',2)
xlabel('Time t');

% lo que afecta es la velocidad de decaimiento, que se puede ver en la vida
% media:
line([0,10], [y0/2, y0/2], 'color','k');

%%% esta ode tiene solucin analtica, la podemos encontrar con matlab con
%%% los comandos (comentados):
%syms x(t) x0 a
%dsolve(diff(x) == -a*x, x(0) == x0)

x_t_analyt=@(x0, a, t) x0*exp(-a.*t);
% Obviamente, entonces si graficamos esta funcin, nos debe dar el mismo resultado que con la integracin numrica:

plot(t, x_t_analyt(y0, a, t), 'sg',  'MarkerSize',10)

axis square % se ve ms bonita as la grfica

ylim([0, y0]);

legend('decay rate a=1', 'a=10', 'y(0)/2', 'solucin analtica (a=10)');

title('decaimiento lineal: estado estacionario (yss=0) insensible a cambios en a')
%%%% cul es el estado estacionario?
% I.e. los valores de y tal que  0= -y*a -->0, para tod a. qu podemos
% decir del parmetro a? no afecta al sistema.
 
 
%% caso 2: Produccin lineal

linear_production=@(t,y, parameters)parameters(1) -y*parameters(2);


a=1;
b=1;

parameters=[a,b];

y0=0;

tspan = [0 10];
[t,y] = ode45(@(t,y)linear_production(t,y,parameters),tspan,y0,parameters);

figure;

subplot(1,2,1)
plot(t,y(:,1),'color','b', 'LineWidth',2)
hold on

% aumentamos la produccin
b=10;
[t,y] = ode45(@(t,y)linear_production(t,y,[a,b]),tspan,y0,[a,b]);
plot(t,y(:,1),'color','r', 'LineWidth',2)
xlabel('Time t');
ylabel('y(t) produccin lineal');

% esta ode tiene solucin analtica
%syms x(t) x0 a b
%dsolve(diff(x) == b-a*x, x(0) == x0)
 %(b - exp(-a*t)*(b - a*x0))/a
 
 
%%%% cul es el estado estacionario?
 
 % I.e. los valores de y tal que  0= b-a*x -->b/a. AHora s, hay una dependencia paramtrica. podemos ver
 % cmo el parmetro b afecta el estado estacionario, aunque este comportamiento es trivial: podemos ver
 % desde la ecuacin que es una relacin lineal, una recta con inclinacin 1/a.
 a=1;
 b=[0:0.1:100];
 subplot(1,2,2);
 plot(b, b./a)
 xlabel('b');
 ylabel('y steady state');
 


 