close all
clear all
clc


%%%%% Ejemplo de un sistema bi-estable%%%%%%%%
%  Angeli D, Ferrell JE, Sontag ED. Detection of multistability, bifurcations, and hysteresis in a large class of biological positive-feedback systems. PNAS [Internet] 2004;101:18227. Available from: http://www.pubmedcentral.nih.gov/articlerender.fcgi?artid=357011&tool=pmcentrez&rendertype=abstract

% Parametros:
alpha1=1; alpha2=1; beta1=200; beta2=10;gamma1=4;
gamma2=4; K1=30; K2=1;
% Parametros de bifurcacin:
v=1;


% Ecuacin diferencial: en la funcin Angeli.m
%dydt = [alpha1*(1-y(1))-beta1*y(1)*(v*y(2))^gamma1/(K1+(v*y(2))^gamma1);  
%        alpha2*(1-y(2))-beta2*y(2)*(y(1))^gamma2/(K2+(y(1))^gamma2)];
    

% Primero, un anlisis dinmico - integracin numrica del sistema, 
tspan = [0 100];
y0 = [0 ; 0];
[t,yl] = ode45(@Angeli,tspan,y0, v);

plot(t,yl(:,2),'k')
title('Angeli 2004');
hold on

%%
% Ahora, una segunda condicin inicial
y0 = [0 ; 0.9];
[t,yh] = ode45(@Angeli,tspan,y0,v);

plot(t,yh(:,2),'r')
xlabel('Time t');
ylabel('Solution y (wee)');


%%%% Vemos que el sistema puede converger a dos puntos de equilibrio...
low_ss=[yl(end,1); yl(end,2)];
high_ss=[yh(end,1); yh(end,2)];



scatter(t(end),yl(end,2), 'filled', 'k');
scatter(t(end),yh(end,2), 'filled', 'r');


%% Dos estados : dependencia de condiciones iniciales - podemos entonces hacer lo mismo, pero para varias condiciones iniciales
figure(2)
hold on
xlabel('Time t');
ylabel('Solution y (wee)');

figure(3)
hold on

for ii=1:1:100
    y0 = [rand; rand];
    [t,y] = ode45(@Angeli,tspan,y0, v);
    
    figure(2)
    if abs(y(end,2)-yl(end,2))<0.2
        figure(2)
        plot(t,y(:,2),'k')
        
        
        
        figure(3)
        plot(y(:,1),y(:,2),'k')
        
    else
        figure(2)
        plot(t,y(:,2),'r')
        figure(3)
        plot(y(:,1),y(:,2),'r')
        
    end
end;
 
figure(3)
xlabel('x(0)');
ylabel('y(0)');

%%


% Separatrices??
% Calcular de manera numrica los puntos de equilibrio
% myfun = @(x) [alpha1*(1-x(1))-beta1*x(1)*(v*x(2))^gamma1/(K1+(v*x(2))^gamma1),alpha2*(1-x(2))-beta2*x(2)*(x(1))^gamma2/(K2+(x(1))^gamma2)];% parameterized function
% %fun = @(x)myfun(x,v);    % function of x alone
% fzero(fun,[1;1])
%syms x1 y1
%dotx=alpha1*(1-x1)-beta1*x1*(v*y1)^gamma1/(K1+(v*y1)^gamma1);
%doty=alpha2*(1-y1)-beta2*y1*(x1)^gamma2/(K2+(x1)^gamma2);
% Problema: no se pueden calcular los estados estacionarios de manera analtica
%dydt = [alpha1*(1-y(1))-beta1*y(1)*(v*y(2))^gamma1/(K1+(v*y(2))^gamma1);  
 %       alpha2*(1-y(2))-beta2*y(2)*(y(1))^gamma2/(K2+(y(1))^gamma2)];

% steady_states = solve([dotx==0, doty==0], [x1, y1]);% hold on



